/**
 * @file
 * Interrupts checkout continuation with the SnapPay HPP.
 */

/**
 * The SnapPay HPP JavaScript expects to make use of a global $ aliased jQuery
 * object even though that is not how Drupal uses the library. Short of cloning
 * and correcting their JavaScript, we simply need to check to see if it's
 * defined already and, if not, define it.
 */
if (typeof $ === 'undefined') {
  $ = jQuery;
}

(function ($) {
  Drupal.snappayHpp = {
    processResponse: function() {
      $('#commerce-checkout-form-review').submit();
    }
  };

  Drupal.behaviors.commerce_snappay_hpp = {
    attach: function (context, settings) {
      $("body").delegate("#edit-continue", "click", function (event) {
        event.preventDefault();

        var template = document.querySelector("#snappay_hppform");
        var script = $("<script />");

        var attributeNames = [
          'id',
          'src',
          'data-target',
          'data-callback',
          'data-accountid',
          'data-customerid',
          'data-currencycode',
          'data-transactionamount',
          'data-merchantid',
          'data-paymentmode',
          'data-cvvrequired',
          'data-enableemailreceipt',
          'data-redirectionurl',
          'data-snappayurl',
          'data-udf0',
          'data-udf1',
          'data-udf2',
          'data-udf3',
          'data-udf4',
          'data-udf5',
          'data-udf6',
          'data-udf7',
          'data-udf8',
          'data-udf9',
          'data-firstname',
          'data-lastname',
          'data-addressline1',
          'data-city',
          'data-state',
          'data-zip',
          'data-country',
          'data-email',
          'data-phonenumber',
          'data-signature'
        ];

        attributeNames.forEach((attributeName) =>
          script.attr(attributeName, template.getAttribute(attributeName)),
        );

        $("body").append(script);
      });
    },
  };
})(jQuery);

/**
 * SnapPay's JavaScript assumes the callback function will be in the global
 * window scope, so we alias here to a function on the Drupal object.
 */
var commerce_snappay_hpp_process_response = Drupal.snappayHpp.processResponse;
